package com.persagy.dmp.rwd.digital.domain;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.io.Serializable;
import java.util.Date;

/**
 * 记录关系的计算标记表,与dt_relation表为一对一关系
 * @TableName dt_relation_cal_sign
 */
@TableName(value ="dt_relation_cal_sign")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class RelationCalSign implements Serializable {
    /**
     * 主键id,与dt_relation保持一致
     */
    @TableId(value = "id")
    private String id;

    /**
     * 计算标记 1 为手动 2为自动
     */
    @TableField(value = "sign")
    private Integer sign;

    /**
     * 创建时间,格式为yyyyMMddHHmmss
     */
    @TableField(value = "creation_time")
    private String creationTime;

    /**
     * 更新时间,格式为yyyyMMddHHmmss
     */
    @TableField(value = "modified_time")
    private String modifiedTime;

    /**
     * 合法标记,true-有效,false-无效
     */
    @TableField(value = "valid")
    private Byte valid;

    /**
     * 乐观锁
     */
    @TableField(value = "ts")
    private Date ts;

    @TableField(exist = false)
    private static final long serialVersionUID = 1L;

    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        RelationCalSign other = (RelationCalSign) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getSign() == null ? other.getSign() == null : this.getSign().equals(other.getSign()))
            && (this.getCreationTime() == null ? other.getCreationTime() == null : this.getCreationTime().equals(other.getCreationTime()))
            && (this.getModifiedTime() == null ? other.getModifiedTime() == null : this.getModifiedTime().equals(other.getModifiedTime()))
            && (this.getValid() == null ? other.getValid() == null : this.getValid().equals(other.getValid()))
            && (this.getTs() == null ? other.getTs() == null : this.getTs().equals(other.getTs()));
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getSign() == null) ? 0 : getSign().hashCode());
        result = prime * result + ((getCreationTime() == null) ? 0 : getCreationTime().hashCode());
        result = prime * result + ((getModifiedTime() == null) ? 0 : getModifiedTime().hashCode());
        result = prime * result + ((getValid() == null) ? 0 : getValid().hashCode());
        result = prime * result + ((getTs() == null) ? 0 : getTs().hashCode());
        return result;
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", sign=").append(sign);
        sb.append(", creationTime=").append(creationTime);
        sb.append(", modifiedTime=").append(modifiedTime);
        sb.append(", valid=").append(valid);
        sb.append(", ts=").append(ts);
        sb.append(", serialVersionUID=").append(serialVersionUID);
        sb.append("]");
        return sb.toString();
    }
}